@@ -37,7 +37,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(new_user_amazon run_aws_cmd get_aws_security_id
                  launch_server $configure_aws1 $pem_file $credpath
-                 $aws_configure $aws connect_shell);
+                 $aws_configure $aws connect_shell cmd_raw);
 our $pem_file='';
 our $credpath='.';
 our $aws={};
