@@ -1268,6 +1268,132 @@ END
 
 };
 
+our $gnusocial_lift_restrictions=sub {
+
+   my $inform_banner=<<'END';
+
+    _    _  __ _     ___        _       _    _   _
+   | |  (_)/ _| |_  | _ \___ __| |_ _ _(_)__| |_(_)___ _ _  ___
+   | |__| |  _|  _| |   / -_|_-<  _| '_| / _|  _| / _ \ ' \(_-<
+   |____|_|_|  \__| |_|_\___/__/\__|_| |_\__|\__|_\___/_||_/__/
+
+END
+   $inform_banner.=<<END;
+   New Amazon email users are confined to the Amazon SES (Simple Email
+   Service) "sandbox". Within the sandbox there is a limit of 200 emails
+   every 24 hours. More importantly, *ALL* recipients have to be "Amazon
+   verified" - which is burdensome. To lift these restrictions, you have
+   to apply for a "limit increase". A limit increase will also remove the
+   requirement that recipients be Amazon verified. Note - there is *NO*
+   guarantee that Amazon will lift email restrictions for any particular
+   user. Use this link to apply for a limit increase:
+
+   http://docs.aws.amazon.com/ses/latest/DeveloperGuide/request-production-access.html
+END
+   my $lift_restrictions={
+
+      Name => 'lift_restrictions',
+      Result => sub { return '{gnusocial_ses_sandbox}<' },
+      Banner => $inform_banner,
+   };
+   return $lift_restrictions;   
+
+};
+
+our $gnusocial_use_limited=sub {
+
+   my $inform_banner=<<'END';
+
+    _   _           _    _       _ _          _   ___            _ _
+   | | | |___ ___  | |  (_)_ __ (_) |_ ___ __| | | __|_ __  __ _(_) |
+   | |_| (_-</ -_) | |__| | '  \| |  _/ -_) _` | | _|| '  \/ _` | | |
+    \___//__/\___| |____|_|_|_|_|_|\__\___\__,_| |___|_|_|_\__,_|_|_|
+
+END
+   $inform_banner.=<<END;
+   Since there is no guarantee that Amazon will lift email restrictions for
+   any particular user, it is helpful to know how to make the most of the
+   access there actually is. Users who have not requested, or been granted a
+   limit increase, must verify thier recipients with Amazon. Once verified,
+   GNU Social features like notifications will work for that recipient. To
+   verify a recipient, use the form in the link below to enter the recipient's
+   email address. Amazon will automatically send a verification email that
+   they must respond to. You are highly encouraged to communicate with your
+   recipient through some other medium (other email, text message, Facebook,
+   Twitter, etc.) Be aware that recipients of these verification emails have
+   a link to inform Amazon if the email was "unwanted". Once they are verified,
+   you can successfully send an invite to them from your GNU Social server.
+
+   http://docs.aws.amazon.com/ses/latest/DeveloperGuide/verify-email-addresses.html
+END
+   my $use_limited_email={
+
+      Name => 'use_limited_email',
+      Result => sub { return '{gnusocial_ses_sandbox}<' },
+      Banner => $inform_banner,
+   };
+   return $use_limited_email;
+
+
+};
+
+our $gnusocial_ses_sandbox=sub {
+
+   my $inform_banner=<<'END';
+
+    ___                     _            _     _____        _ 
+   |_ _|_ __  _ __  ___ _ _| |_ __ _ _ _| |_  |_   _|_ _ __| |__ __
+    | || '  \| '_ \/ _ \ '_|  _/ _` | ' \  _|   | |/ _` (_-< / /(_-<
+   |___|_|_|_| .__/\___/_|  \__\__,_|_||_\__|   |_|\__,_/__/_\_\/__/ 
+     __      |_|    _                            ___            _ _
+    / _|___ _ _    /_\  _ __  __ _ ______ _ _   | __|_ __  __ _(_) |
+   |  _/ _ \ '_|  / _ \| '  \/ _` |_ / _ \ ' \  | _|| '  \/ _` | | |
+   |_| \___/_|   /_/ \_\_|_|_\__,_/__\___/_||_| |___|_|_|_\__,_|_|_|
+
+END
+   $inform_banner.=<<END;
+   In order to use email invites and notifications from your GNU Social
+   server, there is an important and necessary task you will have to do
+   outside of this FullAuto installation. New Amazon users are allowed very
+   limited and precise access to email functionality. Given the ever present
+   problem of "spam", and other forms of email abuse, this policy is quite
+   reasonable. Unfortunately, email dependent features of GNU Social are
+   limited until these restrictions are lifted. Please make a selection:
+
+END
+
+   my $gnusocial_ses_sandbox={
+
+      Name => 'gnusocial_ses_sandbox',
+      Item_1 => {
+      
+         Text => 'Continue Installation of GNU Social.',
+         Result =>
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_choose_strong_password,
+      },
+      Item_2 => {
+
+         Text => 'Learn how to use limited email with Amazon restrictions.',
+         Result =>
+      $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_use_limited,
+
+      },
+      Item_3 => {
+
+         Text => 'Learn how to apply for removal of Amazon email restrictions.',
+         Result =>
+      $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_lift_restrictions,
+
+      },
+      Scroll => 1,
+      Banner => $inform_banner,
+
+   };
+   return $gnusocial_ses_sandbox;
+
+
+};
+
 our $gnusocial_validate_email=sub {
 
    package gnusocial_validate_email;
@@ -1315,7 +1441,8 @@ END
 
       Name => 'email_message',
       Result =>
-   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_choose_strong_password,
+   #$Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_choose_strong_password,
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_ses_sandbox,
       Banner => $inform_banner,
 
    };
@@ -1473,7 +1600,7 @@ END
             Text => "]C[",
             Convey => \@identities,
             Result =>
-         $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_choose_strong_password,
+         $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_ses_sandbox,
 
          },
          Scroll => 2,
